@@ -77,12 +77,12 @@ def convert_to_python_type(val: Any, data_type: DataType) -> Any:
 
 
 def validate_and_process_record(
-    dataset: Union[Dataset[IO[str]], Dataset[IO[bytes]]],
     record: RecordType,
     schema: Schema,
     seen_ids: Set[str],
     existing_ids: Set[str],
     base_directory: pathlib.Path = pathlib.Path(""),
+    disable_filepath_checks: bool = False,
 ) -> Tuple[Optional[RecordType], Optional[str], Optional[RowWarningsType]]:
     """
     Validate the row against the provided schema; generate warnings where issues are found
@@ -153,7 +153,7 @@ def validate_and_process_record(
                         ValidationWarning.TYPE_MISMATCH,
                     )
             elif col_feature_type == FeatureType.filepath:
-                if schema.metadata.modality == Modality.image:
+                if schema.metadata.modality == Modality.image and not disable_filepath_checks:
                     image_filepath = get_image_filepath(base_directory, column_value)
                     if not image_file_exists(image_filepath):
                         msg, warn_type = (
@@ -621,7 +621,7 @@ def process_dataset(
         dataset.read_streaming_records(), total=len(dataset), initial=0, leave=True, unit=" rows"
     ):
         row, row_id, warnings = validate_and_process_record(
-            dataset, record, schema, seen_ids, existing_ids, base_directory=dataset_dir
+            record, schema, seen_ids, existing_ids, base_directory=dataset_dir
         )
         update_log_with_warnings(log, row_id, warnings)
         # row and row ID both present, i.e. row will be uploaded
